import time, sys
import RPi.GPIO as GPIO

GPIO.setmode(GPIO.BCM)
LED_PIN = 18
GPIO.setup(LED_PIN, GPIO.OUT)

class Relay:
    def __init__(self, db):
        self.db = db

    def logit(message):
        print(message)
        sys.stdout.flush()

    def blink(self, loop_count=2, sleep=1.0):
        count = 0
        while count <= loop_count:
            GPIO.output(LED_PIN, GPIO.HIGH)
            self.db.set_key("led_state", "high")
            print(self.db.get_value_by_key("led_state"))
            time.sleep(sleep)

            GPIO.output(LED_PIN, GPIO.LOW)
            self.db.set_key("led_state", "low")
            print(self.db.get_value_by_key("led_state"))
            time.sleep(sleep)

            count += 1


from aosong import am2315
import time, json

class TempRh:
    def __init__(self, db):
        self.db = db
        self.sensor = am2315.Sensor()

    def get_data(self):
        tuple_data = self.sensor.data()
        j = {
            "humidity": tuple_data[0],
            "c": tuple_data[1],
            "f": tuple_data[2]
        }
        temp_rh = json.dumps(j)
        self.db.set_key('temp_rh', temp_rh)
        return temp_rh


from .comm import Comm
from .device_am2315 import TempRh
from .device_srd_dc03v_sl_c import Relay

db = Comm(host='ec2-75-101-199-232.compute-1.amazonaws.com',
         port=7599,
         password='p525f81fc5bf9a369922112084c158114e3978bc3042d9a76172a8508c7cd26ce')

tempRh = TempRh(db)
relay = Relay(db)

while True:
    temp_rh = tempRh.get_data()
    relay.blink(5)
    print(temp_rh)